# This file was auto-generated by salt's setup on Tuesday, 13 December 2016 @ 23:12:49 UTC.

from salt.version import SaltStackVersion

__saltstack_version__ = SaltStackVersion(2016, 11, 1, 0, '', 0, 0, None)
